<?php
/*
Plugin Name: Tweetmeme Button
Plugin URI: http://tweetmeme.com/button.php
Description: Adds the tweetmeme button into your posts and RSS feed.
Version: 1.2
Author: fav.or.it
Author URI: http://fav.or.it
*/

function tm_options() {
    add_options_page('Tweetmeme Settings', 'Tweetmeme', 8, __FILE__, 'tm_options_page');
}

function tm_update($content) {
    
    if (get_option('tm_display_page') == null) {
        if (is_page()) {
            return $content;
        }
    }
    
    if (get_option('tm_display_feed') == null) {
        if (is_feed()) {
            return $content;
        }
    }
    
    $button = '<div id="tweetmeme_button" style="' . get_option('tm_style') . '">
                    <script type="text/javascript">
                    //<![CDATA[
                        tweetmeme_url = \'' . get_permalink() . '\';';
                        
    if (get_option('tm_source')) {
        $button .= 'tweetmeme_source = \'' . get_option('tm_source') . '\';';
    } 
                    
    if (get_option('tm_version') == 'compact') {
        $button .= 'tweetmeme_style = \'compact\';';
    }
    
    $button .= '//]]>';
    
    $button .= '</script><script type="text/javascript" src="http://tweetmeme.com/i/scripts/button.js"></script>
                </div>';
    
    // Before and After code added by http://www.jimyaghi.com
    if (get_option('tm_where') == 'beforeandafter') {
        return $button . $content . $button;
    }
    else if (get_option('tm_where') == 'before') {
        return $button . $content;
    } else {
        return $content . $button;
    }

}

// Remove the filter excerpts
// Code added by Soccer Dad
function tm_remove_filter($content) {
    remove_action('the_content', 'tm_update');
    return $content;
}

function tm_ping($post_id) {
    // do we have curl
    if (function_exists('curl_init')) {
        $url = get_permalink($post_id);
        // create a new cURL resource
        $ch = curl_init();

        // set URL and other appropriate options
        curl_setopt($ch, CURLOPT_URL, 'http://api.tweetmeme.com/ping.php?url=' . urlencode($url));
        curl_setopt($ch, CURLOPT_HEADER, 0);

        // grab URL and pass it to the browser
        curl_exec($ch);

        // close cURL resource, and free up system resources
        curl_close($ch);    
    }
}

function tm_options_page() {
?>
    <div class="wrap">
    <div class="icon32" id="icon-options-general"><br/></div><h2>Settings for Tweetmeme Integration</h2>
    <p>This plugin will install the tweetmeme widget for each of your blog posts in both the content of your posts and the RSS feed. 
    It can be easily styles in your blog posts and is referenced by the id <code>tweetmeme_button</code>. 
    </p>
    <form method="post" action="options.php">
    <?php wp_nonce_field('update-options'); ?> 
        <table class="form-table">
            <tr>
                <th scope="row">
                    Position
                </th>
                <td>
                    <p>
                        <input type="radio" value="before" <?php if (get_option('tm_where') == 'before') echo 'checked="checked"'; ?> name="tm_where" group="tm_where"/> 
                        <label for="tm_where">Before the content of your post</label>     
                    </p>
                    <p>
                        <input type="radio" value="after" <?php if (get_option('tm_where') == 'after') echo 'checked="checked"'; ?> name="tm_where" group="tm_where" />
                        <label for="tm_where">After the content of your post</label>    
                    </p>
                    <p>
                        <input type="radio" value="beforeandafter" <?php if (get_option('tm_where') == 'beforeandafter') echo 'checked="checked"'; ?> name="tm_where" group="tm_where"/> 
                        <label for="tm_where">Before AND After the content of your post</label>     
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    Type
                </th>
                <td>
                    <p>
                        <input type="radio" value="large" <?php if (get_option('tm_version') == 'large') echo 'checked="checked"'; ?> name="tm_version" group="tm_version"/> 
                        <label for="tm_where">The normal size widget</label>     
                    </p>
                    <p>
                        <input type="radio" value="compact" <?php if (get_option('tm_version') == 'compact') echo 'checked="checked"'; ?> name="tm_version" group="tm_version" />
                        <label for="tm_where">The compact widget</label>    
                    </p>
                </td>
            </tr> 
            <tr>
                <th scope="row">
                    Display
                </th>
                <td>
                    <p>
                        <input type="checkbox" value="1" <?php if (get_option('tm_display_page') == '1') echo 'checked="checked"'; ?> name="tm_display_page" group="tm_display"/> 
                        <label for="tm_display_page">Display the button on pages</label>     
                    </p>
                    <p>
                        <input type="checkbox" value="1" <?php if (get_option('tm_display_feed') == '1') echo 'checked="checked"'; ?> name="tm_display_feed" group="tm_display" />
                        <label for="tm_display_feed">Display the button on your feed</label>    
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    Source
                </th>
                <td>
                    <p>
                        <input type="text" value="<?php echo get_option('tm_source'); ?>" name="tm_source" /> 
                        <label for="tm_source">Change the RT source of the button from RT @tweetmeme</label>    <br/>
                        <span class="setting-description">We are currently experimenting with whitelisting twitter accounts. This will only work if your account has been whitelisted by tweetmeme. For more information please see the <a href="http://help.tweetmeme.com">help</a>.</span> 
                    </p>
                </td>
            </tr>  
            <tr>
                <th scope="row"><label for="tm_style">Styling</label></th>
                <td>
                    <input type="text" value="<?php echo get_option('tm_style'); ?>" name="tm_style" />
                    <span class="setting-description">Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code></span>
                </td>
            </tr>
        </table>
        <input type="hidden" name="action" value="update" />
        <input type="hidden" name="page_options" value="tm_where,tm_style,tm_version,tm_display_page,tm_display_feed,tm_source" />
        <p class="submit">
            <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
        </p>
    </form>
    </div>
<?php
}

add_action('admin_menu', 'tm_options');
 
add_filter('the_content', 'tm_update');
add_filter('get_the_excerpt', 'tm_remove_filter', 9); 

add_action('publish_post', 'tm_ping', 9);

add_option('tm_where');
add_option('tm_style', 'float: left; margin-right: 10px;');
  
add_option('tm_version', 'large'); 
add_option('tm_display_page', '1');
add_option('tm_display_feed', '1');

?>